@@ -17,15 +17,11 @@ log = logging.getLogger(__name__)
 
 # Provide libmagic support in terms of binaries under Windows.
 if sys.platform == "win32":
-    if sys.maxsize != 0x7fffffff:
-        os.environ["PATH"] = "%s;%s" % (
-            data_file("win64"), os.environ["PATH"]
-        )
+    if sys.maxsize != 0x7FFFFFFF:
+        os.environ["PATH"] = "%s;%s" % (data_file("win64"), os.environ["PATH"])
         magic_file = data_file("win64", "magic.mgc")
     else:
-        os.environ["PATH"] = "%s;%s" % (
-            data_file("win32"), os.environ["PATH"]
-        )
+        os.environ["PATH"] = "%s;%s" % (data_file("win32"), os.environ["PATH"])
         magic_file = data_file("win32", "magic.mgc")
 
 # Therefore only import libmagic at this point.
@@ -35,12 +31,14 @@ if sys.platform == "win32":
     magic._instances[False] = magic.Magic(mime=False, magic_file=magic_file)
     magic._instances[True] = magic.Magic(mime=True, magic_file=magic_file)
 
+
 def from_file(f, mime=False):
     try:
         return magic.from_file(f, mime)
     except magic.MagicException as e:
         return e.message
 
+
 def from_buffer(buf, mime=False):
     try:
         return magic.from_buffer(buf, mime)
